@@ -1,5 +1,5 @@
 # $File: /local/member/autrijus/Parse-AFP//lib/Parse/AFP/PTX.pm $ $Author: autrijus $
-# $Revision: #9 $ $Change: 3918 $ $DateTime: 2004-02-17T10:05:07.533350Z $
+# $Revision: #7 $ $Change: 2431 $ $DateTime: 2004-02-19T22:41:00.737029Z $
 
 package Parse::AFP::PTX;
 use base 'Parse::AFP::Record';
@@ -9,7 +9,7 @@ use constant SUBFORMAT => (
     'PTX::ControlSequence' => ['C/a* X', '*'],
 );
 
-sub refresh {
+sub _refresh {
     my ($self) = @_;
 
     foreach my $member ($self->members) {
@@ -27,12 +27,10 @@ sub refresh {
     $self->SUPER::refresh;
 }
 
-sub load_struct {
-    my ($self, $data) = @_;
+# sub load_struct {
     # XXX - first get the header, then split with 2BD3,
     # then do a step-by-step tokenization to make sure
     # raw text fields get respected
-    $self->set_struct( $self->parser->unformat($$data . $self->padding) );
-}
+# }
 
 1;
