@@ -25,6 +25,8 @@ use constant DISPATCH_TABLE => (
     d3a6af	=> 'PGD',	# Page Descriptor
     d3a6bb	=> 'GDD',	# Graphics Data Descriptor
     d3a6c5	=> 'FGD',	# Form Environment Group Descriptor (O)
+    d3a6e3	=> 'DXD',	# Data Map Transmission Subcase Descriptor
+    d3a6e7	=> 'LND',	# Line Descriptor
     d3a6eb	=> 'BDD',	# Bar Code Data Descriptor
     d3a6fb	=> 'IDD',	# Image Data Descriptor
     d3a77b	=> 'IOC',	# IM Image Output Control (C)
@@ -46,11 +48,14 @@ use constant DISPATCH_TABLE => (
     d3a8c6	=> 'BRG',	# Begin Resource Group
     d3a8c7	=> 'BOG',	# Begin Object Environment Group
     d3a8c9	=> 'BAG',	# Begin Active Environment Group
+    d3a8ca	=> 'BDM',	# Begin Data Map
+    d3a8cb	=> 'BPM',	# Begin Page Map
     d3a8cc	=> 'BMM',	# Begin Medium Map
     d3a8cd	=> 'BFM',	# Begin Form Map
     d3a8ce	=> 'BR',	# Begin Resource (R)
     d3a8d9	=> 'BSG',	# Begin Resource Environment Group
     d3a8df	=> 'BMO',	# Begin Overlay
+    d3a8e3	=> 'BDX',	# Begin Data Map Transmission Subcase
     d3a8eb	=> 'BBC',	# Begin Bar Code Object
     d3a8fb	=> 'BIM',	# Begin Image Object
     d3a95f	=> 'EPS',	# End Page Segment
@@ -68,13 +73,17 @@ use constant DISPATCH_TABLE => (
     d3a9c6	=> 'ERG',	# End Resource Group
     d3a9c7	=> 'EOG',	# End Object Environment Group
     d3a9c9	=> 'EAG',	# End Active Environment Group
+    d3a9ca	=> 'EDM',	# End Data Map
+    d3a9cb	=> 'EPM',	# End Page Map
     d3a9cc	=> 'EMM',	# End Medium Map
     d3a9cd	=> 'EFM',	# End Form Map
     d3a9ce	=> 'ER',	# End Resource (R)
     d3a9d9	=> 'ESG',	# End Resource Environment Group
     d3a9df	=> 'EMO',	# End Overlay
+    d3a9e3	=> 'EDX',	# End Data Map Transmission Subcase
     d3a9eb	=> 'EBC',	# End Bar Code Object
     d3a9fb	=> 'EIM',	# End Image Object
+    d3aae7	=> 'LNC',	# Line Descriptor Count
     d3ab77	=> 'MCA',	# Map Color Attribute Table
     d3ab88	=> 'MMT',	# Map Media Type
     d3ab8a	=> 'MCF',	# Map Coded Font
